pm4py.algo.analysis.workflow\_net package
=========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.analysis.workflow_net.variants

Submodules
----------

pm4py.algo.analysis.workflow\_net.algorithm module
--------------------------------------------------

.. automodule:: pm4py.algo.analysis.workflow_net.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.analysis.workflow\_net.evaluator module
--------------------------------------------------

.. automodule:: pm4py.algo.analysis.workflow_net.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.analysis.workflow_net
   :members:
   :undoc-members:
   :show-inheritance:
